import {FC, useEffect, useState} from "react";
import {Button, Form, Input, View} from "@tarojs/components";
import Taro, {useRouter} from "@tarojs/taro";
import {userApi, loginApi, LoginParams} from "@/api";
import {Profile} from '@/store'
import {getCurrentInstance} from "@tarojs/runtime";
import {regexTel} from "@/utils/regu";

const Meeting: FC = () => {
  const {meeting_id} = getCurrentInstance()?.router?.params as unknown as { meeting_id: string }
  const {setUser, setToken, setCompany} = Profile.useContainer()
  const [h5params, setH5Params] = useState<LoginParams | null>(null)
  const router = useRouter()

  useEffect(() => {
    loginApi.getMeetingParams().then((res) => {
      setH5Params(res)
    })
  }, [])

  Taro.useLoad(() => {
    loginApi.meetingInfo(meeting_id).then(res => {
      if (res !== 1) {
        Taro.showModal({
          title: '二维码已过期',
          success() {
            Taro.reLaunch({url: '/pages/login/login'})
          }
        })
      }
    })
  })

  function submit(e) {
    const value = e.detail.value
    if (!value.user_name || !value.phone_number) {
      Taro.showToast({title: '请认真填写', icon: "error"})
      return
    }

    if (!regexTel.exec(value.phone_number)) {
      Taro.showToast({title: '手机号错误', icon: 'error'})
      return
    }

    if (process.env.TARO_ENV === 'h5') {
      if (h5params == null) {
        Taro.showToast({title: '页面参数错误，请刷新页面！', icon: 'error'})
        return;
      }
      location.href = "https://open.weixin.qq.com/connect/oauth2/authorize?" +
        "appid=" + h5params!.appid +
        "&redirect_uri=" + encodeURIComponent(h5params!.route + `?depid=1&phone_number=${value.phone_number}&user_name=${value.user_name}&meeting_id=${meeting_id}`) +
        "&response_type=code" +
        "&scope=snsapi_userinfo" +
        "#wechat_redirect";

    } else {
      Taro.login({
        success: async (res) => {
          const data = await userApi.meetingSave({
            ...value,
            code: res.code,
            ticket: router.params.ticket,
          })
          setCompany(data.company)
          setUser(data.user)
          setToken(data.token)
          Taro.switchTab({url: '/pages/index/index'})
        },
        fail: () => {
          Taro.showToast({title: '获取微信登录失败', icon: "error"})
        }
      })

    }
  }

  return (
    <View className='h-10 bg-white px-2'>
      <Form className='form' onSubmit={submit}>

        <View className='item'>
          <View>用户名</View>
          <Input placeholder='请输入用户名' focus name='user_name'/>
        </View>

        <View className='item'>
          <View>手机号</View>
          <Input type='number' placeholder='请输入手机号' name='phone_number'/>
        </View>

        <Button className='button mt-3' formType='submit'>登记</Button>
      </Form>
    </View>
  )
}


export default Meeting
